@@ -15,9 +15,8 @@
 #' @importFrom jsonlite fromJSON
 #' @importFrom tibble as_tibble
 #' @examples
-#' \donttest{
-#'   print(news_url_ex)
-#'   getComment(news_url_ex)
+#' \dontrun{
+#'   getComment("https://n.news.naver.com/mnews/article/421/0002484966?sid=100")
 #'}
 
 getComment <- function(turl = url,
@@ -26,11 +25,11 @@ getComment <- function(turl = url,
                        sort = c("favorite", "reply", "old", "new", "best"),
                        type = c("df", "list")) {
   sort <- toupper(sort[1])
-  tem <- strsplit(turl, "[=&]")[[1]]
+  tem <- strsplit(urltools::path(turl), "[/]")[[1]]
   ticket <- "news"
   pool <- "cbox5"
-  oid <- tem[grep("oid", tem) + 1]
-  aid <- tem[grep("aid", tem) + 1]
+  oid <- tem[3]
+  aid <- tem[4]
   templateId <- "view_politics"
   useAltSort <- "&useAltSort=true"
 
@@ -106,9 +105,8 @@ getComment <- function(turl = url,
 #' @importFrom dplyr bind_rows
 #' @export
 #' @examples
-#' \donttest{
-#'   print(news_url_ex)
-#'   getAllComment(news_url_ex)
+#' \dontrun{
+#'   getAllComment("https://n.news.naver.com/mnews/article/214/0001195110?sid=103")
 #'   }
 
 getAllComment <- function(turl = url, ...) {
