@@ -7,17 +7,17 @@
 #' @export
 #' @importFrom rvest read_html html_node html_text
 #' @importFrom httr GET content
+#' @importFrom methods is
 #' @examples
-#' \donttest{
-#'   print(cate_list_url_ex)
-#'   getMaxPageNum(cate_list_url_ex)
+#' \dontrun{
+#'   getMaxPageNum("https://news.naver.com/main/list.naver?mode=LS2D&mid=shm&sid1=103&sid2=376")
 #'   }
 
 getMaxPageNum <- function(turl = url, max = 100) {
   ifmaxUrl <- paste0(turl, "&page=", max)
   hobj <- rvest::read_html(httr::content(httr::GET(ifmaxUrl), "text"))
   noContent <-  rvest::html_node(hobj, "div.no_content")
-  if (class(noContent) == "xml_node") {
+  if (methods::is(noContent, "xml_node")) {
     return("no result")
   }
   ifmax <- rvest::html_node(hobj, "a.next")
